==> 2.0.4.tar.gz: lib/src/utils/model_utils/feed_item_details_util.dart <==
import '../fw_logger_util.dart';
import '../../models/feed_item_details.dart';
import 'video_feed_source_util.dart';

class FeedItemDetailsUtil {
  static FeedItemDetails? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      if (json["source"] is String) {
        final source =
            VideoFeedSourceUtil.createFeedSource(json["source"] as String);
        if (source != null && json["id"] is String) {
          FeedItemDetails details =
              FeedItemDetails(id: json["id"] as String, source: source);

          if (json["index"] is int) {
            details.index = json["index"] as int;
          }

          if (json["duration"] is num) {
            details.duration = (json["duration"] as num).toDouble();
          }

          if (json["title"] is String) {
            details.title = json["title"] as String;
          }

          if (json["channel"] is String) {
            details.channel = json["channel"] as String;
          }

          if (json["playlist"] is String) {
            details.playlist = json["playlist"] as String;
          }

          if (json["playlistGroup"] is String) {
            details.playlistGroup = json["playlistGroup"] as String;
          }

          if (json["dynamicContentParameters"] is Map<dynamic, dynamic>) {
            try {
              final tmpParameters1 = Map<String, dynamic>.from(
                  json["dynamicContentParameters"] as Map<dynamic, dynamic>);
              final tmpParameters2 =
                  Map<String, List<dynamic>>.from(tmpParameters1);
              var resultParameters = <String, List<String>>{};
              tmpParameters2.forEach((key, value) {
                resultParameters[key] = List<String>.from(value);
              });
              details.dynamicContentParameters = resultParameters;
            } catch (e) {
              FWLoggerUtil.log("parse dynamic content parameters error $e");
            }
          }

          if (json["hashtagFilterExpression"] is String) {
            details.hashtagFilterExpression =
                json["hashtagFilterExpression"] as String;
          }

          return details;
        }
      }
    }

    return null;
  }
}

==> 2.4.6.tar.gz: lib/src/utils/model_utils/feed_item_details_util.dart <==
import '../../models/feed_item_details.dart';
import 'video_feed_source_util.dart';

class FeedItemDetailsUtil {
  static FeedItemDetails? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      if (json["source"] is String) {
        final source =
            VideoFeedSourceUtil.createFeedSource(json["source"] as String);
        if (source != null && json["id"] is String) {
          FeedItemDetails details =
              FeedItemDetails(id: json["id"] as String, source: source);

          if (json["index"] is int) {
            details.index = json["index"] as int;
          }

          if (json["duration"] is num) {
            details.duration = (json["duration"] as num).toDouble();
          }

          if (json["title"] is String) {
            details.title = json["title"] as String;
          }

          if (json["channel"] is String) {
            details.channel = json["channel"] as String;
          }

          if (json["playlist"] is String) {
            details.playlist = json["playlist"] as String;
          }

          if (json["playlistGroup"] is String) {
            details.playlistGroup = json["playlistGroup"] as String;
          }

          if (json["dynamicContentParameters"] is Map<dynamic, dynamic>) {
            try {
              final tmpParameters1 = Map<String, dynamic>.from(
                  json["dynamicContentParameters"] as Map<dynamic, dynamic>);
              final tmpParameters2 =
                  Map<String, List<dynamic>>.from(tmpParameters1);
              var resultParameters = <String, List<String>>{};
              tmpParameters2.forEach((key, value) {
                resultParameters[key] = List<String>.from(value);
              });
              details.dynamicContentParameters = resultParameters;
            } catch (e) {
              // FWLoggerUtil.log("parse dynamic content parameters error $e");
            }
          }

          if (json["hashtagFilterExpression"] is String) {
            details.hashtagFilterExpression =
                json["hashtagFilterExpression"] as String;
          }

          return details;
        }
      }
    }

    return null;
  }
}
